@@ -1,6 +1,6 @@
 package Devel::Camelcadedb;
 # must be quoted to work correctly with JSON protocol
-our $VERSION = "v2021.1"; # DO NOT REMOVE FUCKING v, IT KEEPS PROPER VERSIONING
+our $VERSION = "v2021.2"; # DO NOT REMOVE FUCKING v, IT KEEPS PROPER VERSIONING
 
 # to ensure protocol compatibility between the IDE and the debugger, we will use $API_VERSION variable, to be able
 # to bump debugger version without necessity to update IDE part.
@@ -460,7 +460,7 @@ sub _get_reference_subelements
         }
         elsif ($reftype eq 'REF')
         {
-            push @$data, _get_reference_descriptor( $source_data, \$$source_data );
+            push @$data, _get_reference_descriptor($source_data, $$source_data);
         }
         elsif ($reftype eq 'GLOB')
         {
@@ -550,7 +550,7 @@ sub _from_utf8
 
 sub _get_reference_descriptor
 {
-    my ($name, $value, $uniq_map) = @_;
+    my ($name, $value) = @_;
 
     my $key = $value;
     my $reftype = Scalar::Util::reftype( $value );
@@ -567,7 +567,6 @@ sub _get_reference_descriptor
     my $fileno = undef;
     my $rendered = undef;
     my $rendered_error = \0;
-    my $error = undef;
     my $tied;
 
     if (!$reftype)
@@ -584,20 +583,13 @@ sub _get_reference_descriptor
         $is_utf = defined $$value && utf8::is_utf8( $$value ) ? \1 : \0;
         $value = defined $$value ? "\"$$value\"" : 'undef'; #_escape_scalar(
     }
-    elsif ($reftype eq 'REF')
-    {
-        $uniq_map //= {};
-        if( exists $uniq_map->{$type} ){
-            $value = "Cyclic reference to $type";
-            $error = 1;
-        }
-        else{
-            $uniq_map->{$type} = 1;
-            my $result = _get_reference_descriptor( $name, $$value, $uniq_map );
-            $result->{ref_depth}++;
-            return $result;
-        }
-
+    elsif ($reftype eq 'REF') {
+        $type = overload::StrVal($$value) || 'unknown';
+        $tied = tied $value;
+        $size = 1;
+        $expandable = \1;
+        $ref_depth = 1;
+        $ref = undef; # to prevent rendering data
     }
     elsif ($reftype eq 'ARRAY')
     {
@@ -698,18 +690,7 @@ sub _get_reference_descriptor
     }
     $result->{layers} = $layers if $layers;
     $result->{fileno} = "".$fileno if defined $fileno;
-    if( $tied){
-        $uniq_map //= {};
-        if( exists $uniq_map->{$type} ){
-            $result->{tied_with} = "Cyclic reference to $type";
-            $result->{error} = \1;
-        }
-        else {
-            $uniq_map->{$type} = 1;
-            $result->{tied_with} = _get_reference_descriptor(object => $tied, $uniq_map);
-        }
-    }
-    $result->{error} = \1 if $error;
+    $result->{tied_with} = _get_reference_descriptor(object => $tied) if $tied;
 
     return $result;
 }
